==> v0.5.tar.gz: welco/welco/contrib/alfortville/urls.py <==
# welco - multichannel request processing
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import patterns, url

from .views import (dgs, dga, copies, copies_ajax, table_info, table_avis,
        table_mandatory_avis, table_waiting, count_dgs, count_dga, count_info,
        count_avis, count_mandatory_avis)

urlpatterns = patterns('',
    url('^dgs/$', dgs, name='alfortville-dgs'),
    url('^dga/$', dga, name='alfortville-dga'),
    url('^copies/(?P<pk>\w+)/$', copies, name='alfortville-copies'),
    url('^ajax/copies/(?P<pk>\w+)/$', copies_ajax, name='alfortville-copies-ajax'),
    url('^table/info/$', table_info, name='alfortville-table-info'),
    url('^table/avis/$', table_avis, name='alfortville-table-avis'),
    url('^table/avis-requis/$', table_mandatory_avis, name='alfortville-table-mandatory-avis'),
    url('^table/en-attente-de-validation/$', table_waiting, name='alfortville-table-waiting'),

    url(r'^ajax/count/dgs/$', count_dgs, name='alfortville-count-dgs'),
    url(r'^ajax/count/dga/$', count_dga, name='alfortville-count-dga'),
    url(r'^ajax/count/info/$', count_info, name='alfortville-count-info'),
    url(r'^ajax/count/avis/$', count_avis, name='alfortville-count-avis'),
    url(r'^ajax/count/avis-requis/$', count_mandatory_avis, name='alfortville-count-avis-requis'),
)

==> v0.23.tar.gz: welco/welco/contrib/alfortville/urls.py <==
# welco - multichannel request processing
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import patterns, url

from .views import (dgs, dga, copies, copies_ajax, table_info, table_avis,
        table_mandatory_avis, table_waiting, count_dgs, count_dga, count_info,
        count_avis, count_mandatory_avis)

urlpatterns = patterns('',
    url(r'^dgs/(?P<table>table/)?$', dgs, name='alfortville-dgs'),
    url(r'^dga/(?P<table>table/)?$', dga, name='alfortville-dga'),
    url('^copies/(?P<pk>\w+)/$', copies, name='alfortville-copies'),
    url('^ajax/copies/(?P<pk>\w+)/$', copies_ajax, name='alfortville-copies-ajax'),
    url('^table/info/$', table_info, name='alfortville-table-info'),
    url('^table/avis/$', table_avis, name='alfortville-table-avis'),
    url('^table/avis-requis/$', table_mandatory_avis, name='alfortville-table-mandatory-avis'),
    url('^table/en-attente/$', table_waiting, name='alfortville-table-waiting'),

    url(r'^ajax/count/dgs/$', count_dgs, name='alfortville-count-dgs'),
    url(r'^ajax/count/dga/$', count_dga, name='alfortville-count-dga'),
    url(r'^ajax/count/info/$', count_info, name='alfortville-count-info'),
    url(r'^ajax/count/avis/$', count_avis, name='alfortville-count-avis'),
    url(r'^ajax/count/avis-requis/$', count_mandatory_avis, name='alfortville-count-avis-requis'),
)
